@@ -23,7 +23,7 @@ from ai.backend.client.output.types import FieldSpec, PaginatedResult
 from ..compat import current_loop
 from ..config import DEFAULT_CHUNK_SIZE, MAX_INFLIGHT_CHUNKS
 from ..exceptions import BackendClientError
-from ..pagination import generate_paginated_results
+from ..pagination import fetch_paginated_result
 from ..request import Request
 from .base import BaseFunction, api_function
 
@@ -37,6 +37,7 @@ _default_list_fields = (
     vfolder_fields["group_id"],
     vfolder_fields["permission"],
     vfolder_fields["ownership_type"],
+    vfolder_fields["status"],
 )
 
 
@@ -111,7 +112,7 @@ class VFolder(BaseFunction):
         :param group: Fetch vfolders in a specific group.
         :param fields: Additional per-vfolder query fields to fetch.
         """
-        return await generate_paginated_results(
+        return await fetch_paginated_result(
             "vfolder_list",
             {
                 "group_id": (group, "UUID"),
@@ -590,6 +591,13 @@ class VFolder(BaseFunction):
         async with rqst.fetch() as resp:
             return await resp.text()
 
+    @api_function
+    @classmethod
+    async def list_shared_vfolders(cls):
+        rqst = Request("GET", "folders/_/shared")
+        async with rqst.fetch() as resp:
+            return await resp.json()
+
     @api_function
     @classmethod
     async def shared_vfolder_info(cls, vfolder_id: str):
